pilot.impl.pilotdata_manager.DataUnitItem

Package pilot :: Package impl :: Module pilotdata_manager :: Class DataUnitItem |

# Class DataUnitItem

source code

DataUnitItem

Instance Methods
__init__(self, pd=None, local_url=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__repr__(self) repr(x) | source code
to_dict(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods
create_data_unit_list(cls, pd=None, urls=None) Creates a list of DUs from URL list | source code
create_data_unit_from_urls(cls, pd=None, urls=None) Creates a list of DUs from URL list | source code
create_data_unit_from_dict(cls, du_dict) | source code

Class Variables
| DUI_ID_PREFIX = ``'``dui-``'``

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, pd=None, local_url=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)